==> nextcloud-25.0.2-4-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/es.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Enlace público",
    "Photos" : "Fotos",
    "Your memories under your control" : "Sus recuerdos bajo su control",
    "All media" : "Todos los medios",
    "Videos" : "Vídeos",
    "Albums" : "Álbumes",
    "Collaborative albums" : "Álbumes colaborativos",
    "People" : "Personas",
    "Folders" : "Carpetas",
    "Favorites" : "Favoritos",
    "On this day" : "En este día",
    "Shared with you" : "Compartido contigo",
    "Tags" : "Etiquetas",
    "Locations" : "Ubicaciones",
    "Photos settings" : "Configuración de fotos",
    "Mark selection as favorite" : "Marcar selección como favorita",
    "Add selection to favorites" : "Añadir selección a favoritos",
    "Remove selection from favorites" : "Eliminar selección de favoritos",
    "Name of the album" : "Nombre del álbum",
    "Location of the album" : "Ubicación del álbum",
    "Go back to the previous view." : "Regresar a la vista anterior.",
    "Back" : "Atrás",
    "Go to the add collaborators view." : "Ir a la vista de añadir colaboradores.",
    "Add collaborators" : "Añadir colaboradores",
    "Save." : "Guardar.",
    "Create the album." : "Crear el álbum",
    "Save" : "Guardar",
    "Create album" : "Crear álbum",
    "Back to the new album form." : "Regresar al formulario de álbum nuevo.",
    "Add to Album" : "Añadir al álbum",
    "Add selection to album {albumName}" : "Añadir selección al álbum {albumName}",
    "Create a new album." : "Crear un álbum nuevo.",
    "Create new album" : "Crear nuevo álbum",
    "New album" : "Nuevo álbum",
    "_%n item_::_%n photos and videos_" : ["%n ítem","%n fotos y videos","%n fotos y videos"],
    "_Share with %n user_::_Share with %n users_" : ["Compartir con %n usuario","Compartir con %n usuarios","Compartir con %n usuarios"],
    "Add people or groups who can edit your album" : "Añada personas o grupos que puedan editar su álbum",
    "Search for collaborators" : "Buscar colaboradores",
    "Search people or groups" : "Buscar personas o grupos",
    "Add {collaboratorLabel} to the collaborators list" : "Añadir {collaboratorLabel} a la lista de colaboradores",
    "No collaborators available" : "No hay colaboradores disponibles",
    "Remove {collaboratorLabel} from the collaborators list" : "Eliminar {colaboratorLabel} de la lista de colaboradores",
    "Copy the public link" : "Copiar enlace público",
    "Public link copied!" : "¡Se copió el enlace público!",
    "Copy public link" : "Copiar enlace público",
    "Delete the public link" : "Borrar el enlace público",
    "Share via public link" : "Compartir a través de enlace público",
    "Failed to fetch collaborators list." : "Fallo al recuperar la lista de colaboradores.",
    "Failed to fetch album." : "Fallo al recuperar el álbum.",
    "Failed to update album." : "Fallo al actualizar el álbum.",
    "This collection does not exist" : "Esta colección no existe",
    "An error occurred" : "Ocurrió un error",
    "_%n photos_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Select image {imageName}" : "Seleccionar imagen {imageName}",
    "The file is in the favorites" : "El archivo se encuentra en los favoritos",
    "Open the full size \"{name}\" image" : "Abrir la imagen \"{name}\" a tamaño completo",
    "There are no photos or videos yet!" : "¡No hay fotos ni videos todavía!",
    "Add to {destination}" : "Añadir a {destination}",
    "Open the \"{name}\" sub-directory" : "Abrir el subdirectorio \"{name}\"",
    "Back to {folder}" : "Atrás a {folder}",
    "Share this folder" : "Compartir esta carpeta",
    "_{years} year ago_::_{years} years ago_" : ["Hace {years} año","Hace {years} años","Hace {years} años"],
    "Enable squared photos view" : "Habilitar vista de fotos cuadradas",
    "Default Photos upload and Albums location" : "Ubicación por defecto de subida para fotos y álbumes",
    "Select the default location for your media" : "Seleccione la ubicación por defecto para sus medios",
    "Invalid location selected" : "Se seleccionó una ubicación inválida",
    "View" : "Ver",
    "Photos directory" : "Carpeta de fotos",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Manage collaborators for this album" : "Administrar colaboradores para este álbum",
    "Open actions menu" : "Abrir menú de acciones",
    "Edit album details" : "Editar los detalles del álbum",
    "Download all files in album" : "Descargar todos los archivos del álbum",
    "Delete album" : "Eliminar álbum",
    "Download selected files" : "Descargar archivos seleccionados",
    "Remove selection from album" : "Eliminar selección del álbum",
    "This album does not have any photos or videos yet!" : "¡Este álbum no tiene fotos ni videos todavía!",
    "Add photos to this album" : "Añadir fotos a este álbum",
    "Add photos to the album" : "Añadir fotos al álbum",
    "Manage collaborators" : "Administrar colaboradores",
    "Save collaborators for this album." : "Guardar colaboradores para este álbum",
    "Cover photo for album {albumName}" : "Foto de cubierta para el álbum {albumName}",
    "There is no album yet!" : "¡No hay álbum todavía!",
    "This person could not be found" : "Esta persona no pudo ser encontrada",
    "Rename person" : "Renombrar persona",
    "Merge with different person" : "Unir con una persona diferente",
    "Download selected photos" : "Descargar fotos seleccionadas",
    "Favorite" : "Marcar como favorito",
    "Remove from favorites" : "Eliminar de favoritos",
    "Remove person" : "Eliminar persona",
    "Name of this person" : "Nombre de esta persona",
    "Merge person" : "Unir persona",
    "_Remove photo from person_::_Remove photos from person_" : ["Eliminar foto de la persona","Eliminar fotos de la persona","Eliminar fotos de la persona"],
    "This might take some time depending on the size of your photo library." : "Esto podría tomar algún tiempo dependiendo del tamaño de su biblioteca de fotos.",
    "Recognized people will show up here" : "Las personas que logren ser reconocidas se mostrarán aquí",
    "This folder does not exist" : "Esta carpeta no existe",
    "Loading folders …" : "Cargando carpetas ...",
    "No photos in here" : "No hay fotos aquí",
    "Failed to fetch albums list." : "Fallo al recuperar la lista de álbumes.",
    "Shared albums" : "Álbumes compartidos",
    "Cover photo for shared album {albumName}." : "Foto de cubierta para el álbum compartido {albumName}.",
    "Back to tags overview" : "Regresar a la vista general de etiquetas",
    "No photos with this tag yet" : "No hay fotos con esta etiqueta todavía",
    "No tags yet" : "Todavía no hay etiquetas",
    "Photos with tags will show up here" : "Las fotos con etiquetas aparecerán aquí",
    "Popular tags" : "Etiquetas populares",
    "Add" : "Añadir",
    "Create a new album" : "Crear un álbum nuevo",
    "Add selection to an album" : "Añadir selección a un álbum",
    "Add to album" : "Añadir al álbum",
    "Delete selection" : "Borrar la selección",
    "No photos or videos in here" : "No se encuentran fotos ni videos aquí",
    "Failed to fetch faces list." : "Fallo al recuperar la lista de caras.",
    "All your media" : "Todos sus medios",
    "Tagged photos" : "Fotos etiquetadas",
    "Failed to create {albumName}." : "Fallo al crear {albumName}",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Fallo al renombrar {currentAlbumName} a {newAlbumName}.",
    "Failed to rename {oldName} to {faceName}." : "Fallo al renombrar {oldName} a {faceName}",
    "Failed to delete {faceName}." : "Fallo al borrar {faceName}",
    "Failed to delete {fileId}." : "Fallo al borrar {fileId}.",
    "Failed to delete {fileName}." : "Fallo al borrar {fileName}.",
    "Failed to set favorite state for {fileId}." : "Fallo al establecer el estado de favoritos para {fileId}.",
    "Failed to set favorite state for {fileName}." : "Fallo al establecer el estado de favoritos para {fileName}.",
    "Your photos" : "Tus fotos",
    "Your videos" : "Tus vídeos",
    "Your folders" : "Tus carpetas",
    "Settings" : "Ajustes"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-26.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/es.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Enlace público",
    "Photos" : "Fotos",
    "Your memories under your control" : "Sus recuerdos bajo su control",
    "All media" : "Todos los medios",
    "Videos" : "Vídeos",
    "Albums" : "Álbumes",
    "Collaborative albums" : "Álbumes colaborativos",
    "People" : "Personas",
    "Folders" : "Carpetas",
    "Favorites" : "Favoritos",
    "On this day" : "En este día",
    "Shared with you" : "Compartido contigo",
    "Tags" : "Etiquetas",
    "Places" : "Ubicaciones",
    "Map" : "Mapas",
    "Photos settings" : "Configuración de fotos",
    "Mark selection as favorite" : "Marcar selección como favorita",
    "Add selection to favorites" : "Añadir selección a favoritos",
    "Remove selection from favorites" : "Eliminar selección de favoritos",
    "Name of the album" : "Nombre del álbum",
    "Location of the album" : "Ubicación del álbum",
    "Go back to the previous view." : "Regresar a la vista anterior.",
    "Back" : "Atrás",
    "Go to the add collaborators view." : "Ir a la vista de añadir colaboradores.",
    "Add collaborators" : "Añadir colaboradores",
    "Save." : "Guardar.",
    "Create the album." : "Crear el álbum",
    "Save" : "Guardar",
    "Create album" : "Crear álbum",
    "Back to the new album form." : "Regresar al formulario de álbum nuevo.",
    "Add to Album" : "Añadir al álbum",
    "Add selection to album {albumName}" : "Añadir selección al álbum {albumName}",
    "Create a new album." : "Crear un álbum nuevo.",
    "Create new album" : "Crear nuevo álbum",
    "New album" : "Nuevo álbum",
    "_%n item_::_%n photos and videos_" : ["%n ítem","%n fotos y videos","%n fotos y videos"],
    "_Share with %n user_::_Share with %n users_" : ["Compartir con %n usuario","Compartir con %n usuarios","Compartir con %n usuarios"],
    "Add people or groups who can edit your album" : "Añada personas o grupos que puedan editar su álbum",
    "Search for collaborators" : "Buscar colaboradores",
    "Search people or groups" : "Buscar personas o grupos",
    "Add {collaboratorLabel} to the collaborators list" : "Añadir {collaboratorLabel} a la lista de colaboradores",
    "No collaborators available" : "No hay colaboradores disponibles",
    "Remove {collaboratorLabel} from the collaborators list" : "Eliminar {colaboratorLabel} de la lista de colaboradores",
    "Copy the public link" : "Copiar enlace público",
    "Public link copied!" : "¡Se copió el enlace público!",
    "Copy public link" : "Copiar enlace público",
    "Delete the public link" : "Borrar el enlace público",
    "Share via public link" : "Compartir a través de enlace público",
    "Failed to fetch collaborators list." : "Fallo al recuperar la lista de colaboradores.",
    "Failed to fetch album." : "Fallo al recuperar el álbum.",
    "Failed to update album." : "Fallo al actualizar el álbum.",
    "This collection does not exist" : "Esta colección no existe",
    "An error occurred" : "Ocurrió un error",
    "_%n photos_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Select image {imageName}" : "Seleccionar imagen {imageName}",
    "The file is in the favorites" : "El archivo se encuentra en los favoritos",
    "Open the full size \"{name}\" image" : "Abrir la imagen \"{name}\" a tamaño completo",
    "There are no photos or videos yet!" : "¡No hay fotos ni videos todavía!",
    "Add to {destination}" : "Añadir a {destination}",
    "Open the \"{name}\" sub-directory" : "Abrir el subdirectorio \"{name}\"",
    "Back to {folder}" : "Atrás a {folder}",
    "Share this folder" : "Compartir esta carpeta",
    "_{years} year ago_::_{years} years ago_" : ["Hace {years} año","Hace {years} años","Hace {years} años"],
    "Enable squared photos view" : "Habilitar vista de fotos cuadradas",
    "Default Photos upload and Albums location" : "Ubicación por defecto de subida para fotos y álbumes",
    "Select the default location for your media" : "Seleccione la ubicación por defecto para sus medios",
    "Invalid location selected" : "Se seleccionó una ubicación inválida",
    "View" : "Ver",
    "Photos directory" : "Carpeta de fotos",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Manage collaborators for this album" : "Administrar colaboradores para este álbum",
    "Open actions menu" : "Abrir menú de acciones",
    "Edit album details" : "Editar los detalles del álbum",
    "Download all files in album" : "Descargar todos los archivos del álbum",
    "Delete album" : "Eliminar álbum",
    "Download selected files" : "Descargar archivos seleccionados",
    "Remove selection from album" : "Eliminar selección del álbum",
    "This album does not have any photos or videos yet!" : "¡Este álbum no tiene fotos ni videos todavía!",
    "Add photos to this album" : "Añadir fotos a este álbum",
    "Add photos to the album" : "Añadir fotos al álbum",
    "Manage collaborators" : "Administrar colaboradores",
    "Save collaborators for this album." : "Guardar colaboradores para este álbum",
    "Cover photo for album {albumName}" : "Foto de cubierta para el álbum {albumName}",
    "There is no album yet!" : "¡No hay álbum todavía!",
    "This person could not be found" : "Esta persona no pudo ser encontrada",
    "Rename person" : "Renombrar persona",
    "Merge with different person" : "Unir con una persona diferente",
    "Download selected photos" : "Descargar fotos seleccionadas",
    "Favorite" : "Marcar como favorito",
    "Remove from favorites" : "Eliminar de favoritos",
    "Remove person" : "Eliminar persona",
    "Name of this person" : "Nombre de esta persona",
    "Merge person" : "Unir persona",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover foto a una persona diferente","Mover fotos a una persona diferente","Mover fotos a una persona diferente"],
    "_Remove photo from person_::_Remove photos from person_" : ["Eliminar foto de la persona","Eliminar fotos de la persona","Eliminar fotos de la persona"],
    "This might take some time depending on the size of your photo library." : "Esto podría tomar algún tiempo dependiendo del tamaño de su biblioteca de fotos.",
    "Recognized people will show up here" : "Las personas que logren ser reconocidas se mostrarán aquí",
    "This folder does not exist" : "Esta carpeta no existe",
    "Loading folders …" : "Cargando carpetas ...",
    "No photos in here" : "No hay fotos aquí",
    "This place does not have any photos or videos yet!" : "¡Esta ubicación no tiene fotos ni videos todavía!",
    "Add photos to this place" : "Añadir fotos a esta ubicación",
    "Cover photo for place {placeName}" : "Foto de cubierta para la ubicación {placeName}",
    "There is no place yet!" : "¡Todavía no hay ubicación!",
    "Failed to fetch albums list." : "Fallo al recuperar la lista de álbumes.",
    "Shared by" : "Compartido por",
    "Shared albums" : "Álbumes compartidos",
    "Cover photo for shared album {albumName}." : "Foto de cubierta para el álbum compartido {albumName}.",
    "Back to tags overview" : "Regresar a la vista general de etiquetas",
    "No photos with this tag yet" : "No hay fotos con esta etiqueta todavía",
    "No tags yet" : "Todavía no hay etiquetas",
    "Photos with tags will show up here" : "Las fotos con etiquetas aparecerán aquí",
    "Popular tags" : "Etiquetas populares",
    "Add" : "Añadir",
    "Create a new album" : "Crear un álbum nuevo",
    "Add selection to an album" : "Añadir selección a un álbum",
    "Add to album" : "Añadir al álbum",
    "Delete selection" : "Borrar la selección",
    "No photos or videos in here" : "No se encuentran fotos ni videos aquí",
    "Failed to fetch collection." : "Fallo al recuperar la colección.",
    "Failed to fetch collections list." : "Fallo al recuperar la lista de colecciones.",
    "Failed to fetch faces list." : "Fallo al recuperar la lista de caras.",
    "All your media" : "Todos sus medios",
    "Album {title}" : "Álbum {title}",
    "Shared Albums" : "Álbumes compartidos",
    "Shared album {title}" : "Álbum compartido {title}",
    "Public album {title}" : "Álbum público {title}",
    "Tagged photos" : "Fotos etiquetadas",
    "Tagged photo {title}" : "Foto etiquetada {title}",
    "{title}'s face" : "Rostro de {title}",
    "Failed to create {albumName}." : "Fallo al crear {albumName}",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Fallo al renombrar {currentAlbumName} a {newAlbumName}.",
    "Failed to rename {oldName} to {faceName}." : "Fallo al renombrar {oldName} a {faceName}",
    "Failed to delete {faceName}." : "Fallo al borrar {faceName}",
    "Failed to delete {fileId}." : "Fallo al borrar {fileId}.",
    "Failed to delete {fileName}." : "Fallo al borrar {fileName}.",
    "Failed to set favorite state for {fileId}." : "Fallo al establecer el estado de favoritos para {fileId}.",
    "Failed to set favorite state for {fileName}." : "Fallo al establecer el estado de favoritos para {fileName}.",
    "Your photos" : "Tus fotos",
    "Your videos" : "Tus vídeos",
    "Your folders" : "Tus carpetas",
    "Locations" : "Ubicaciones",
    "Settings" : "Ajustes"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
